flutter_inject library

A simple dependency injection widget based on standard Flutter's InheritedWidget

Classes

Dependency<T>
The Dependency class allows you to retrieve any dependency previously injected:
Inject<T>
The widget that allows you to inject any dependency:
InjectAll
The widget that allows you to inject many dependencies at once glad to the Dependency class: